@@ -11,7 +11,10 @@
 # You should have received a copy of the GNU General Public License along with django-ca.  If not,
 # see <http://www.gnu.org/licenses/>.
 
+"""Keep track of internal settings for django-ca."""
+
 import os
+import re
 from datetime import timedelta
 
 from cryptography.hazmat.primitives import hashes
@@ -150,6 +153,14 @@ _CA_CRL_PROFILES = {
     }
 }
 
+# Get and sanitize default CA serial
+# NOTE: This effectively duplicates utils.sanitize_serial()
+CA_DEFAULT_CA = getattr(settings, 'CA_DEFAULT_CA', '').replace(':', '').upper()
+if CA_DEFAULT_CA != '0':
+    CA_DEFAULT_CA = CA_DEFAULT_CA.lstrip('0')
+if re.search('[^0-9A-F]', CA_DEFAULT_CA):
+    raise ImproperlyConfigured('CA_DEFAULT_CA: %s: Serial contains invalid characters.' % CA_DEFAULT_CA)
+
 CA_DEFAULT_SUBJECT = getattr(settings, 'CA_DEFAULT_SUBJECT', {})
 
 # Add ability just override/add some profiles
@@ -174,6 +185,12 @@ CA_NOTIFICATION_DAYS = getattr(settings, 'CA_NOTIFICATION_DAYS', [14, 7, 3, 1, ]
 CA_CRL_PROFILES = getattr(settings, 'CA_CRL_PROFILES', _CA_CRL_PROFILES)
 CA_PASSWORDS = getattr(settings, 'CA_PASSWORDS', {})
 
+# ACME settings
+ACME_ORDER_VALIDITY = getattr(settings, 'CA_ACME_ORDER_VALIDITY', timedelta(hours=1))
+ACME_ACCOUNT_REQUIRES_CONTACT = getattr(settings, 'CA_ACME_ACCOUNT_REQUIRES_CONTACT', True)
+ACME_MAX_CERT_VALIDITY = getattr(settings, 'CA_ACME_MAX_CERT_VALIDITY', timedelta(days=90))
+ACME_DEFAULT_CERT_VALIDITY = getattr(settings, 'CA_ACME_DEFAULT_CERT_VALIDITY', timedelta(days=90))
+
 # Undocumented options, e.g. to share values between different parts of code
 CA_MIN_KEY_SIZE = getattr(settings, 'CA_MIN_KEY_SIZE', 2048)
 
@@ -183,10 +200,17 @@ CA_DIGEST_ALGORITHM = getattr(settings, 'CA_DIGEST_ALGORITHM', "sha512").strip()
 try:
     CA_DIGEST_ALGORITHM = getattr(hashes, CA_DIGEST_ALGORITHM)()
 except AttributeError:
+    # pylint: disable=raise-missing-from; not really useful in this context
     raise ImproperlyConfigured('Unkown CA_DIGEST_ALGORITHM: %s' % settings.CA_DIGEST_ALGORITHM)
 
 if isinstance(CA_DEFAULT_EXPIRES, int):
     CA_DEFAULT_EXPIRES = timedelta(days=CA_DEFAULT_EXPIRES)
+if isinstance(ACME_MAX_CERT_VALIDITY, int):
+    ACME_MAX_CERT_VALIDITY = timedelta(days=ACME_MAX_CERT_VALIDITY)
+if isinstance(ACME_DEFAULT_CERT_VALIDITY, int):
+    ACME_DEFAULT_CERT_VALIDITY = timedelta(days=ACME_DEFAULT_CERT_VALIDITY)
+if isinstance(ACME_ORDER_VALIDITY, int):
+    ACME_ORDER_VALIDITY = timedelta(days=ACME_ORDER_VALIDITY)
 elif not isinstance(CA_DEFAULT_EXPIRES, timedelta):
     raise ImproperlyConfigured('CA_DEFAULT_EXPIRES: %s: Must be int or timedelta' % CA_DEFAULT_EXPIRES)
 if CA_DEFAULT_EXPIRES <= timedelta():
@@ -201,6 +225,7 @@ try:
     if not isinstance(CA_DEFAULT_ECC_CURVE, ec.EllipticCurve):
         raise ImproperlyConfigured('%s: Not an EllipticCurve.' % _CA_DEFAULT_ECC_CURVE)
 except AttributeError:
+    # pylint: disable=raise-missing-from; not really useful in this context
     raise ImproperlyConfigured('Unkown CA_DEFAULT_ECC_CURVE: %s' % settings.CA_DEFAULT_ECC_CURVE)
 
 CA_FILE_STORAGE = getattr(settings, 'CA_FILE_STORAGE', global_settings.DEFAULT_FILE_STORAGE)
@@ -212,16 +237,19 @@ CA_FILE_STORAGE_KWARGS = getattr(settings, 'CA_FILE_STORAGE_KWARGS', {
 
 CA_FILE_STORAGE_URL = 'https://django-ca.readthedocs.io/en/latest/update.html#update-to-1-12-0-or-later'
 
+CA_ENABLE_ACME = getattr(settings, 'CA_ENABLE_ACME', False)
+
 # Decide if we should use Celery or not
 CA_USE_CELERY = getattr(settings, 'CA_USE_CELERY', None)
 if CA_USE_CELERY is None:
     try:
-        from celery import shared_task  # NOQA
+        from celery import shared_task  # pylint: disable=unused-import
         CA_USE_CELERY = True
     except ImportError:
         CA_USE_CELERY = False
 elif CA_USE_CELERY is True:
     try:
-        from celery import shared_task  # NOQA
+        from celery import shared_task  # NOQA: F401
     except ImportError:
+        # pylint: disable=raise-missing-from; not really useful in this context
         raise ImproperlyConfigured('CA_USE_CELERY set to True, but Celery is not installed')
