@@ -20,6 +20,7 @@ from textwrap import indent
 from cryptography import x509
 from cryptography.hazmat.primitives.serialization import Encoding
 
+from django.core.exceptions import ImproperlyConfigured
 from django.core.management.base import BaseCommand as _BaseCommand
 from django.core.management.base import CommandError
 from django.core.management.base import OutputWrapper
@@ -270,6 +271,18 @@ class BaseCommand(_BaseCommand):
         else:
             super(BaseCommand, self).__init__(stdout, stderr, no_color=no_color)
 
+    def dump(self, path, data):
+        """Dump `data` to `path` (``-`` means stdout)."""
+
+        if path == '-':
+            self.stdout.write(data, ending=b'')
+        else:
+            try:
+                with open(path, 'wb') as stream:
+                    stream.write(data)
+            except IOError as ex:
+                raise CommandError(ex) from ex
+
     def execute(self, *args, **options):
         if self.binary_output is True:
             if options.get('stdout'):  # pragma: no branch
@@ -298,13 +311,27 @@ class BaseCommand(_BaseCommand):
     def add_subject(self, parser, arg='subject', metavar=None, help=None):
         parser.add_argument(arg, action=SubjectAction, metavar=metavar, help=help)
 
-    def add_ca(self, parser, arg='--ca',
-               help='Certificate authority to use (default: %(default)s).',
+    def add_ca(self, parser, arg='--ca', help='Certificate authority to use (default: %(default)s).',
                allow_disabled=False, no_default=False, allow_unusable=False):
+        """Add the ``--ca`` action.
+
+        Parameters
+        ----------
+
+        parser
+        arg : str, optional
+        help : str, optional
+        allow_disabled : bool, optional
+        no_default : bool, optional
+        allow_unusable : bool, optional
+        """
         if no_default is True:
             default = None
         else:
-            default = CertificateAuthority.objects.enabled().first()
+            try:
+                default = CertificateAuthority.objects.default()
+            except ImproperlyConfigured:
+                default = None
 
         help = help % {'default': add_colons(default.serial) if default else None}
         parser.add_argument('%s' % arg, metavar='SERIAL', help=help, default=default,
@@ -463,22 +490,56 @@ class CertCommand(BaseCommand):
         super(CertCommand, self).add_arguments(parser)
 
 
-class CertificateAuthorityDetailMixin(object):
-    def add_ca_args(self, parser):
+class CertificateAuthorityDetailMixin:
+    """Mixin to add common arguments to init_ca and edit_ca."""
+
+    def add_general_args(self, parser, default=''):  # pylint: disable=no-self-use
+        """Add some general arguments."""
+
+        group = parser.add_argument_group('General', 'General information about the CA.')
+        group.add_argument('--caa', default=default, metavar='NAME', help='CAA record for this CA.')
+        group.add_argument('--website', default=default, metavar='URL', action=URLAction,
+                           help='Browsable URL for the CA.')
+        group.add_argument('--tos', default=default, metavar='URL', action=URLAction,
+                           help='Terms of service URL for the CA.')
+
+    def add_acme_group(self, parser):  # pylint: disable=no-self-use
+        """Add configuration for ACMEv2."""
+
+        if not ca_settings.CA_ENABLE_ACME:
+            return
+
+        group = parser.add_argument_group('ACMEv2', 'ACMEv2 configuration.')
+
+        enable_group = group.add_mutually_exclusive_group()
+        enable_group.add_argument('--acme-enable', dest='acme_enabled', action='store_true', default=None,
+                                  help="Enable ACMEv2 support.")
+        enable_group.add_argument('--acme-disable', dest='acme_enabled', action='store_false',
+                                  help='Disable ACMEv2 support.')
+
+        disable_group = group.add_mutually_exclusive_group()
+        disable_group.add_argument(
+            '--acme-contact-optional', dest='acme_requires_contact', action='store_false', default=None,
+            help="Do not require email address during ACME account registration.")
+
+        disable_group.add_argument(
+            '--acme-contact-required', dest='acme_requires_contact', action='store_true',
+            help="Require email address during ACME account registration.")
+
+    def add_ca_args(self, parser):  # pylint: disable=no-self-use
+        """Add CA arguments."""
+
         group = parser.add_argument_group(
             'X509 v3 certificate extensions for signed certificates',
             'Extensions added when signing certificates.')
         group.add_argument('--issuer-url', metavar='URL', action=URLAction,
                            help='URL to the certificate of your CA (in DER format).')
         group.add_argument(
-            '--issuer-alt-name', metavar='URL', action=ExtensionAction, extension=IssuerAlternativeName,
+            '--issuer-alt-name', metavar='URL', action=AlternativeNameAction, extension=IssuerAlternativeName,
             help='URL to the homepage of your CA.'
         )
         group.add_argument(
             '--crl-url', metavar='URL', action=MultipleURLAction, default=[],
             help='URL to a certificate revokation list. Can be given multiple times.'
         )
-        group.add_argument(
-            '--ocsp-url', metavar='URL', action=URLAction,
-            help='URL of an OCSP responder.'
-        )
+        group.add_argument('--ocsp-url', metavar='URL', action=URLAction, help='URL of an OCSP responder.')
