@@ -78,7 +78,7 @@ class CertificateManagerMixin:  # pylint: disable=too-few-public-methods
             if isinstance(ext, x509.extensions.Extension):
                 builder = builder.add_extension(ext.value, critical=ext.critical)
             elif isinstance(ext, Extension):
-                builder = builder.add_extension(**ext.for_builder())
+                builder = builder.add_extension(*ext.for_builder())
             else:
                 raise ValueError('Cannot add extension of type %s' % type(ext).__name__)
         return builder
@@ -274,7 +274,7 @@ class CertificateAuthorityManager(CertificateManagerMixin, models.Manager):
             if not isinstance(name_constraints, NameConstraints):
                 name_constraints = NameConstraints(name_constraints)
 
-            builder = builder.add_extension(**name_constraints.for_builder())
+            builder = builder.add_extension(*name_constraints.for_builder())
 
         if extra_extensions:
             builder = self._extra_extensions(builder, extra_extensions)
