@@ -11,6 +11,14 @@
 # You should have received a copy of the GNU General Public License along with django-ca. If not, see
 # <http://www.gnu.org/licenses/>.
 
+"""Views for the django-ca app.
+
+.. seealso::
+
+   * https://docs.djangoproject.com/en/dev/topics/class-based-views/
+   * https://django-ca.readthedocs.io/en/latest/python/views.html
+"""
+
 import base64
 import binascii
 import logging
@@ -78,6 +86,7 @@ class CertificateRevocationListView(View, SingleObjectMixin):
     """Value of the Content-Type header used in the response. For CRLs in PEM format, use ``text/plain``."""
 
     def get(self, request, serial):
+        # pylint: disable=missing-function-docstring; standard Django view function
         encoding = parse_encoding(request.GET.get('encoding', self.type))
         cache_key = get_crl_cache_key(serial, algorithm=self.digest, encoding=encoding, scope=self.scope)
 
@@ -141,6 +150,7 @@ class OCSPBaseView(View):
     """If set to ``True``, validate child CAs instead."""
 
     def get(self, request, data):
+        # pylint: disable=missing-function-docstring; standard Django view function
         try:
             data = base64.b64decode(data)
         except binascii.Error:
@@ -148,14 +158,15 @@ class OCSPBaseView(View):
 
         try:
             return self.process_ocsp_request(data)
-        except Exception as e:
+        except Exception as e:  # pylint: disable=broad-except; we really need to catch everything here
             log.exception(e)
             return self.fail()
 
     def post(self, request):
+        # pylint: disable=missing-function-docstring; standard Django view function
         try:
             return self.process_ocsp_request(request.body)
-        except Exception as e:
+        except Exception as e:  # pylint: disable=broad-except; we really need to catch everything here
             log.exception(e)
             return self.fail()
 
@@ -221,7 +232,7 @@ class OCSPView(OCSPBaseView):
     def process_ocsp_request(self, data):
         try:
             ocsp_req = ocsp.load_der_ocsp_request(data)  # NOQA
-        except Exception as e:
+        except Exception as e:  # pylint: disable=broad-except; we really need to catch everything here
             log.exception(e)
             return self.malformed_request()
 
@@ -251,7 +262,7 @@ class OCSPView(OCSPBaseView):
         try:
             responder_key = self.get_responder_key()
             responder_cert = self.get_responder_cert()
-        except Exception:
+        except Exception:  # pylint: disable=broad-except; we really need to catch everything here
             log.error('Could not read responder key/cert.')
             return self.fail()
 
@@ -293,12 +304,13 @@ class OCSPView(OCSPBaseView):
 @method_decorator(csrf_exempt, name='dispatch')
 class GenericOCSPView(OCSPView):
     def dispatch(self, request, serial, **kwargs):
+        # pylint: disable=missing-function-docstring; standard Django view function
         if request.method == 'GET' and 'data' not in kwargs:
             return self.http_method_not_allowed(request, serial, **kwargs)
-        elif request.method == 'POST' and 'data' in kwargs:
+        if request.method == 'POST' and 'data' in kwargs:
             return self.http_method_not_allowed(request, serial, **kwargs)
         self.ca = CertificateAuthority.objects.get(serial=serial)
-        return super(GenericOCSPView, self).dispatch(request, **kwargs)
+        return super().dispatch(request, **kwargs)
 
     def get_ca(self):
         return self.ca
@@ -311,7 +323,14 @@ class GenericOCSPView(OCSPView):
 
 
 class GenericCAIssuersView(View):
+    """Generic view that returns a CA public key in DER format.
+
+    This view serves the URL named in the ``issuers`` key in the
+    :py:class:`~django_ca.extensions.AuthorityInformationAccess` extension.
+    """
+
     def get(self, request, serial):
+        # pylint: disable=missing-function-docstring; standard Django view function
         ca = CertificateAuthority.objects.get(serial=serial)
         data = ca.x509.public_bytes(encoding=Encoding.DER)
         return HttpResponse(data, content_type='application/pkix-cert')
